I/O Utilities
=============

Pandas Integration
------------------

.. automodule:: pydhis2.io.to_pandas
   :members:
   :undoc-members:
   :show-inheritance:

Arrow Integration
-----------------

.. automodule:: pydhis2.io.arrow
   :members:
   :undoc-members:
   :show-inheritance:

Schema Utilities
----------------

.. automodule:: pydhis2.io.schema
   :members:
   :undoc-members:
   :show-inheritance:

